@@ -24,7 +24,7 @@ from diadmin.vctl_cmds.policy import get_policy_list_assignments
 from diadmin.utils.genpwds import gen_pwd
 from diadmin.utils.utils import add_defaultsuffix, csvlist
 
-MAX_DELETE = 3
+MAX_DELETE = 100
 
 
 # Create pwd for new user
@@ -113,16 +113,16 @@ def update_userlist(params, userlist) :
     
 
 def generate_userlist(userlist,
-                      filename = 'userlist.csv',
-                      tenant = 'default',
-                      format = '%firstname %name',
+                      filename='userlist.csv',
+                      tenant='default',
+                      format='%firstname %name',
                       num=10,
-                      user_prefix = 'user-',
+                      user_prefix='user-',
                       pwd='Welcome01!',
-                      pwd_length = 8,
-                      role='STANDARD') :
+                      pwd_length=8,
+                      role='STANDARD'):
     users = list()
-    if userlist :
+    if userlist:
         with open(path.join('users',userlist),mode='r',newline='\n') as csvfile :
             if format == '%firstname %name':
                 csvreader = csv.reader(csvfile,delimiter = ' ')
@@ -135,7 +135,7 @@ def generate_userlist(userlist,
                 for line in csvreader:
                     if line[0][0] == '#' :
                         continue
-                    users.append({'tenant':tenant,'user':line[-1].lower(),'name':' '.join(line),'pwd':gen_pwd(pwd_length),'role':role})
+                    users.append({'tenant':tenant,'user':line[-1].lower(),'name':' '.join(line),'password':gen_pwd(pwd_length),'role':role})
             else :
                 raise ValueError(f'Unknown format: {format}')
     else:
@@ -145,7 +145,7 @@ def generate_userlist(userlist,
             if pwd and pwd != 'RANDOM':
                 newuser['password'] = pwd
             else :
-                newuser['pwd'] = gen_pwd(pwd_length)
+                newuser['password'] = gen_pwd(pwd_length)
             users.append(newuser)
 
     # Test on duplicates
@@ -186,71 +186,74 @@ def main() :
 
     logging.basicConfig(level=logging.INFO)
 
-    description =  "User management.\nPre-requiste: vctl."
+    description = "User management.\nPre-requiste: vctl."
     parser = argparse.ArgumentParser(description=description)
-    parser.add_argument('-c','--config', help = 'Specifies yaml-config file',default='config.yaml')
-    parser.add_argument('-p','--assign_policies', nargs='+', help = 'Assign policies to user in userlist')
-    parser.add_argument('-l','--userlist', help = 'List of user to generate new userlist. If <nameless> userlist without names are generated.')
-    parser.add_argument('-e','--deassign_policies', nargs='+', help = 'Deassign policies from user in userlist')
-    parser.add_argument('-r','--role', help = 'User role with policies defined in config.',default='STANDARD')
-    parser.add_argument('-g','--generate', help = 'Generate userlist with given filename.')
-    parser.add_argument('-o','--output', help = 'Output file of generated userlist',action='store_true')
-    parser.add_argument('-a','--add', help = 'Add users of userlist',action='store_true')
-    parser.add_argument('-d','--delete', help = 'Delete users of userlist',action='store_true')
-    parser.add_argument('-w','--download', help = 'Download user to userlist',action='store_true')
-    parser.add_argument('-s','--assignments', help = 'Download SAP Di user with assignements',action='store_true')
+    parser.add_argument('-c', '--config', help='Specifies yaml-config file', default='config.yaml')
+    parser.add_argument('-p', '--assign_policies', nargs='+', help='Assign policies to user in userlist')
+    parser.add_argument('-l', '--userlist',
+                        help='List of user to generate new userlist. If <nameless> userlist without names are generated.')
+    parser.add_argument('-e', '--deassign_policies', nargs='+', help='Deassign policies from user in userlist')
+    parser.add_argument('-r', '--role', help='User role with policies defined in config.', default='STANDARD')
+    parser.add_argument('-g', '--generate', help='Generate userlist with given filename.')
+    parser.add_argument('-o', '--output', help='Output file of generated userlist', action='store_true')
+    parser.add_argument('-a', '--add', help='Add users of userlist', action='store_true')
+    parser.add_argument('-d', '--delete', help='Delete users of userlist', action='store_true')
+    parser.add_argument('-w', '--download', help='Download user to userlist', action='store_true')
+    parser.add_argument('-s', '--assignments', help='Download SAP Di user with assignements', action='store_true')
 
     args = parser.parse_args()
 
     config_file = args.config
     if args.config:
-        config_file = add_defaultsuffix(args.config,'yaml')
+        config_file = add_defaultsuffix(args.config, 'yaml')
     with open(config_file) as yamls:
         params = yaml.safe_load(yamls)
 
-    if args.generate :
-        if not args.userlist :
-            newuserlist = add_defaultsuffix(args.generate,'csv')
-            logging.info(f'Generic userlist: {newuserlist}')
-            generate_userlist(userlist=None,
-                              filename=newuserlist,
-                              num=params['USERLIST']['NUMBER'],
-                              pwd= params['USERLIST']['PASSWORD'],
-                              pwd_length= params['USERLIST']['PWD_LENGTH'],
-                              tenant=params['TENANT'],
-                              user_prefix=params['USERLIST']['PREFIX'],
-                              role=params['USERLIST']['DEFAULT_ROLE'])
-        else :
+    if args.generate:
+        if args.userlist:
             logging.info(f'Generate userlist from input userlist {args.userlist}')
-            generate_userlist(userlist = args.userlist,
+            generate_userlist(userlist=args.userlist,
                               filename=params['USERLIST']['LIST'],
                               format = params['USERLIST']['FORMAT'],
                               pwd= params['USERLIST']['PASSWORD'],
                               pwd_length= params['USERLIST']['PWD_LENGTH'],
                               tenant=params['TENANT'])
+        else:
+            new_userlist = add_defaultsuffix(args.generate, 'csv')
+            logging.info(f'Generic userlist: {new_userlist}')
+            generate_userlist(userlist=None,
+                              filename=new_userlist,
+                              num=params['USERLIST']['NUMBER'],
+                              pwd=params['USERLIST']['PASSWORD'],
+                              pwd_length=params['USERLIST']['PWD_LENGTH'],
+                              tenant=params['TENANT'],
+                              user_prefix=params['USERLIST']['PREFIX'],
+                              role=params['USERLIST']['DEFAULT_ROLE'])
 
-    userlist = csvlist(path.join('users',params['USERLIST']['LIST']))
+    userlist = csvlist(path.join('users', params['USERLIST']['LIST']))
 
-    if args.add :
+    if args.add:
         di_login(params)
         userlist.with_comments = False
-        userlist.filter = ('status','TO_ADD')
-        for u in userlist :
+        userlist.filter = ('status', 'TO_ADD')
+        for u in userlist:
             if not u['password']:
                 u['password'] = gen_pwd()
+            ret = create_user(u, 'member')
+            if not ret.returncode == 0:
+                continue
             u['status'] = 'EXISTS'
-            create_user(u,'member')
-            deassign_policy(u,'sap.dh.member')
+            deassign_policy(u, 'sap.dh.member')
             policies = params['USER_ROLE'][u['role']]
             assign_policies(u,params["USER_ROLE"][u["role"]])
             logging.info(f'Create user: {u["user"]} with role:{u["role"]} ({policies})')
         userlist.save()
 
-    if args.delete :
+    if args.delete:
         di_login(params)
-        userlist.filter = ('status','TO_DELETE')
+        userlist.filter = ('status', 'TO_DELETE')
         logging.info(f"Delete user marked in user list with \'status\': \'TO_DELETE\'.")
-        for i,u in enumerate(userlist) :
+        for i, u in enumerate(userlist) :
             if i >= MAX_DELETE:
                 break
             delete_user(u)
