@@ -9,12 +9,13 @@ import json
 from os import path
 import urllib
 import logging
-from os.path import join
 import yaml
-from pprint import pprint
-from rdflib import Graph, term
+from rdflib import Graph, Literal, Namespace, URIRef
 import re
+import io
+import csv
 
+from diadmin.connect.connect_neo4j import neo4jConnection
 
 # read availibility_rdf
 def read_availibility_rdf(url) :
@@ -205,6 +206,102 @@ def exfrmt_hierarchy(hierarchies,di_hierarchy) :
             add_di_tag(hierarchies,hierarchy['name'],hierarchy['hierarchy_id'],hierarchy['parent_path'],c)
 
 
+def add_catalog_neo4j(connection) :
+    gdb = neo4jConnection( connection['GRAPHDB']['URL']+':'+str(connection['GRAPHDB']['PORT']), \
+                           connection['GRAPHDB']['USER'], connection['GRAPHDB']['PWD'],connection['GRAPHDB']['DB'])
+    node_tenant = {'label':'TENANT',
+                   'properties':{'tenant':connection['TENANT'],'url':connection['URL']}}
+    gdb.create_node(node_tenant)
+
+    # HIERARCHIES
+    hierarchies = download_hierarchies(connection)
+
+    for t in hierarchies.values():
+        levels = len([c for c in t['path'] if c =='/'])
+        if levels == 0 :
+            node  = {'label':'CATALOG_HIERARCHY',
+                     'properties':{'id':t['hierarchy_id'],'name':t['name']},
+                     'keys':['id']}
+            gdb.create_node(node)
+        else :
+            node = {'label':'CATALOG_TAG',
+                    'properties':{'id':t['tag_id'],'name':t['name'],'path':t['path']},
+                    'keys':['id']}
+            gdb.create_node(node)
+            if levels == 1 :
+                hnode = {'label':'CATALOG_HIERARCHY','properties':{'id':t['hierarchy_id']}}
+                relation_to = {'node_from':hnode,'node_to':node,'relation':{'label':'TAG_CHILD'}}
+                relation_from = {'node_from':node,'node_to':hnode,'relation':{'label':'TAG_HIERARCHY'}}
+                gdb.create_relationship(relation_to)
+                gdb.create_relationship(relation_from)
+            else :
+                pnode = {'label':'CATALOG_TAG','properties':{'path':t['parent_path']}}
+                relation_to = {'node_from':pnode,'node_to':node,'relation':{'label':'TAG_CHILD'}}
+                relation_from = {'node_from':node,'node_to':pnode,'relation':{'label':'TAG_PARENT'}}
+                gdb.create_relationship(relation_to)
+                gdb.create_relationship(relation_from)
+
+
+def add_hierarchy_rdf(connection) :
+
+    # RDF Graph
+    g = Graph()
+    n = Namespace('/'.join([connection['host'],connection['tenant'],'catalog']))
+    g.namespace_manager.bind('catalog',n)
+
+
+    # HIERARCHIES
+    hierarchies = download_hierarchies(connection)
+    '''
+    for t in hierarchies.values():
+        levels = len([c for c in t['path'] if c =='/'])
+        if levels == 0 :
+            n.hierarchy
+            g.add((disystem,'hasHierarchy',))
+            node  = {'label':'CATALOG_HIERARCHY',
+                     'properties':{'id':t['hierarchy_id'],'name':t['name']},
+                     'keys':['id']}
+            gdb.create_node(node)
+        else :
+            node = {'label':'CATALOG_TAG',
+                    'properties':{'id':t['tag_id'],'name':t['name'],'path':t['path']},
+                    'keys':['id']}
+            gdb.create_node(node)
+            if levels == 1 :
+                hnode = {'label':'CATALOG_HIERARCHY','properties':{'id':t['hierarchy_id']}}
+                relation_to = {'node_from':hnode,'node_to':node,'relation':{'label':'TAG_CHILD'}}
+                relation_from = {'node_from':node,'node_to':hnode,'relation':{'label':'TAG_HIERARCHY'}}
+                gdb.create_relationship(relation_to)
+                gdb.create_relationship(relation_from)
+            else :
+                pnode = {'label':'CATALOG_TAG','properties':{'path':t['parent_path']}}
+                relation_to = {'node_from':pnode,'node_to':node,'relation':{'label':'TAG_CHILD'}}
+                relation_from = {'node_from':node,'node_to':pnode,'relation':{'label':'TAG_PARENT'}}
+                gdb.create_relationship(relation_to)
+                gdb.create_relationship(relation_from)
+
+        '''
+
+def csv_hierarchies(connection) :
+    # HIERARCHIES
+    hierarchies = download_hierarchies(connection)
+    tags = list()
+    output = io.StringIO()
+    writer = csv.writer(output)
+    writer.writerow(['PARENT','TAG','DESCRIPTION','PATH','ID','HIERARCHY','HIERARCHY_ID'])
+    for h in hierarchies.values() :
+        if h['parent_path'] =="" and not '/' in h['path'] :
+            continue
+        if h['parent_path'] =="":
+            h['parent_path'] = h['hierarchy_name']
+        parent = h['parent_path'].split('/')[-1]
+        writer.writerow([parent,h['name'],h['description'],h['path'],h['tag_id'],h['hierarchy_name'],h['hierarchy_id']])
+
+    output.seek(0)
+    return output.read()
+
+
+
 #########
 # MAIN
 ########
@@ -215,10 +312,30 @@ def main() :
     with open('config_demo.yaml') as yamls:
         params = yaml.safe_load(yamls)
 
-    conn = {'url':params['URL']+'/app/datahub-app-metadata/api/v1',
+    connection = {'url':params['URL']+'/app/datahub-app-metadata/api/v1',
+                  'host':params['URL'],'tenant':params['TENANT'],
             'auth':(params['TENANT']+'\\'+ params['USER'],params['PWD'])}
 
-    UPLOAD = True
+    if 'GRAPHDB' in params:
+        connection['GRAPHDB'] = params['GRAPHDB']
+        connection['TENANT'] = params['TENANT']
+        connection['URL'] = params['URL']
+
+    gdb = None
+    node_tenant = None
+    NEO4J = False
+    if NEO4J:
+        add_catalog_neo4j(connection)
+
+
+
+    CSV = False
+    if CSV :
+        h_str = csv_hierarchies(connection)
+        with open('catalogs/hierarchies.csv','w') as fp:
+            fp.write(h_str)
+
+    UPLOAD = False
     hierarchy_filename = 'License.json'
     if UPLOAD :
         with open(path.join('catalogs',hierarchy_filename),'r') as fp:
@@ -228,20 +345,25 @@ def main() :
             hierarchies = json.load(fp)
 
         hierarchies = None
-        hierarchies = upload_hierarchies(conn,new_hierarchies,hierarchies)
+        hierarchies = upload_hierarchies(connection,new_hierarchies,hierarchies)
 
     #hierarchy_name = 'License'
     #hierarchy_name = None
-    DOWNLOAD_HIERARCHIES = False
+    DOWNLOAD_HIERARCHIES = True
     if DOWNLOAD_HIERARCHIES :
-        hierarchies = download_hierarchies(conn,hierarchy_name=hierarchy_name)
+        hierarchy_name = None
+        hierarchies = download_hierarchies(connection, hierarchy_name=hierarchy_name)
         filename = 'hierarchies.json'
-        if hierarchy_name :
+        if hierarchy_name:
             filename = hierarchy_name + '.json'
-        with open(path.join('catalogs',filename),'w') as fp:
-            json.dump(hierarchies,fp,indent=4)
+        with open(path.join('catalogs', filename), 'w') as fp:
+            json.dump(hierarchies, fp, indent=4)
+
+    DOWNLOAD_HIERARCHIES_NAMES = False
+    if DOWNLOAD_HIERARCHIES_NAMES:
+        hierarchies = get_hierarchy_names(connection)
+        print(json.dumps(hierarchies,indent=4))
 
 
-
-if __name__ == '__main__' :
+if __name__ == '__main__':
     main()
\ No newline at end of file
