@@ -8,11 +8,9 @@
 #### Doc: https://api.sap.com/api/metadata/resource
 ########################################################
 import logging
-import sys
 from urllib.parse import urljoin
 import urllib
 from os import path
-import re
 import csv
 
 
@@ -23,7 +21,9 @@ import pandas as pd
 
 
 from diadmin.utils.utils import get_system_id
-from diadmin.metadata_api.catalog import download_hierarchies
+from diadmin.metadata_api.catalog import download_hierarchies, add_catalog_neo4j
+from diadmin.metadata_api.connection import get_connections, add_connections_graphdb, get_connection_details
+from diadmin.connect.connect_neo4j import neo4jConnection
 
 
 def re_str(pattern) :
@@ -38,41 +38,17 @@ def re_str(pattern) :
     return re_pat
 
 
-def get_connections(connection,filter_type='',filter_tags=''):
-    logging.info(f"Get Connections of type: {filter_type}")
-    restapi = '/catalog/connections'
-    url = connection['url'] + restapi
-    headers = {'X-Requested-With': 'XMLHttpRequest'}
-    parameter = {"connectionTypes":filter_type}
-    r = requests.get(url, headers=headers, auth=connection['auth'], params=parameter)
-
-    if r.status_code != 200:
-        logging.error(r)
-        return None
-
-    resp = json.loads(r.text)
-    if len(resp) == 0 :
-        logging.info(f"No connections with filter type: {filter_type} - tags: {filter_tags} ")
-
-    connections = dict()
-    for c in resp :
-        connections[c['id']] = {'id':c['id'],'type':c['type'],'description':c['description'],'tags':c['tags'],
-                                   'contentData':c['contentData']}
-    return connections
 
+### CONTAINERS
 def get_containers(connection,containers,container = None,container_filter=None):
 
-    if container == None :
+    if not container:
         container = {'id': 'connectionRoot',
                      'name': 'Root',
                      'qualifiedName': '/',
                      'catalogObjectType': 'ROOT_FOLDER'}
 
-    # exclude internal DI_Data_Lake
-    if re.match('\/*DI_DATA_LAKE',container['qualifiedName']) :
-        return 1
-
-    if not container['id'] == 'connectionRoot' :
+    if not container['id'] == 'connectionRoot':
         container['qualifiedName'] = container['qualifiedName'].strip('/')
         container["parentQualifiedName"] = container['parentQualifiedName'].strip('/')
         containers[container['qualifiedName']] = container
@@ -81,20 +57,122 @@ def get_containers(connection,containers,container = None,container_filter=None)
     restapi = f"/catalog/containers/{container['id']}/children"
     url = connection['url'] + restapi
     headers = {'X-Requested-With': 'XMLHttpRequest'}
-    params = {'containerId': container['id'], 'type':'CONTAINER','$filter': container_filter}
+    params = {'containerId': container['id'], 'type':'CONTAINER', '$filter': container_filter}
     r = requests.get(url, headers=headers, auth=connection['auth'], params=params)
 
     if r.status_code != 200:
-        logging.error(r.status)
+        logging.error(f"Status code: {r.status_code}  - {r.text}")
         return -1
 
     sub_containers = json.loads(r.text)['containers']
     for c in sub_containers:
         get_containers(connection,containers,c,container_filter=container_filter)
-    return containers
+    return
 
 
-def get_datasets(connection, container_id):
+def get_datasets(connection, connection_id, container_name) :
+    logging.info(f"Get container of {container_name}")
+    container_name = urllib.parse.quote(container_name, safe='')
+    restapi = f"/catalog/connections/{connection_id}/containers/{container_name}"
+    url = connection['url'] + restapi
+    headers = {'X-Requested-With': 'XMLHttpRequest'}
+    r = requests.get(url, headers=headers, auth=connection['auth'])
+
+    if r.status_code != 200:
+        logging.error(f"Status code: {r.status_code}  - {r.text}")
+        return -1
+
+    return json.loads(r.text)['datasets']
+
+def get_ids(connection, datasets_ids, containers_ids, container=None) :
+    if container == None:
+        container = {'id': 'connectionRoot',
+                     'name': 'Root',
+                     'qualifiedName': '/',
+                     'catalogObjectType': 'ROOT_FOLDER'}
+    if not container['id'] == 'connectionRoot' :
+        datasets_ids[container['id']] = container['qualifiedName']
+
+    restapi = f"/catalog/containers/{container['id']}/children"
+    url = connection['url'] + restapi
+    headers = {'X-Requested-With': 'XMLHttpRequest'}
+    r = requests.get(url, headers=headers, auth=connection['auth'])
+
+    if r.status_code != 200:
+        logging.error(f"Status code: {r.status_code}  - {r.text}")
+        return -1
+
+    sub_containers = json.loads(r.text)['containers']
+    for c in sub_containers:
+        get_ids(connection, datasets_ids, containers_ids,c)
+    return
+
+
+def get_connection_datasets(connection,connection_id,datasets=None,container=None,with_details = False):
+    if datasets == None:
+        datasets = dict()
+    if container == None :
+        container = {'name': 'Root',
+                     'qualifiedName': '/',
+                     'parentQualifiedName':"/"}
+    elif isinstance(container,str) :
+        path_elements = container.split('/')
+        container = {'name': path_elements[-1],
+                     'qualifiedName': container,
+                     'parentQualifiedName':'/'.join(path_elements[:-1])}
+
+    qualified_name = urllib.parse.quote(container['qualifiedName'],safe='')
+    logging.info(f"Get Connection Containers {connection_id} - {container['qualifiedName']}")
+    restapi = f"catalog/connections/{connection_id}/containers/{qualified_name}/children"
+    url = connection['url'][:-6] + restapi
+    headers = {'X-Requested-With': 'XMLHttpRequest'}
+    r = requests.get(url, headers=headers, auth=connection['auth'])
+
+    if r.status_code != 200:
+        logging.error(f"Status code: {r.status_code}, {r.text}")
+        return -1
+
+    sub_containers = json.loads(r.text)['nodes']
+    for container in sub_containers:
+        if container['isContainer']:
+            get_connection_datasets(connection, connection_id, datasets, container)
+        else:
+            if not with_details:
+                datasets[container['qualifiedName']] = container
+            else:
+                ds = get_dataset_factsheet(connection, connection_id, container['qualifiedName'])
+                datasets[container['qualifiedName']] = ds
+
+    return datasets
+
+def compare_snapshots(latest,current) :
+    new_datasets = [ current[connection][dataset] for connection in current for dataset in current[connection]
+                     if not dataset in latest[connection].keys()]
+    return new_datasets
+
+
+# add GRAPHDB
+def add_containers_graphdb(gdb,containers) :
+    for c in containers.values() :
+        node_container = {'label':'CONTAINER',
+                          'properties':{'id':c['id'],'name':c['name'],'qualifiedName':c['qualifiedName']},
+                          'keys':['id']}
+        gdb.create_node(node_container)
+        if c['parentId'] == 'connectionRoot' :
+            node_connection =  {'label':'CONNECTION',
+                                'properties':{'id':c['connectionId']}}
+            relationship_to = {'node_from':node_container,'node_to':node_connection,'relation':{'label':'PARENT'}}
+            relationship_from = {'node_from':node_connection,'node_to':node_container,'relation':{'label':'CONTAINER'}}
+        else :
+            node_parent =  {'label':'CONTAINER',
+                            'properties':{'id':c['parentId']}}
+            relationship_to = {'node_from':node_container,'node_to':node_parent,'relation':{'label':'PARENT_CONTAINER'}}
+            relationship_from = {'node_from':node_parent,'node_to':node_container,'relation':{'label':'CHILD_CONTAINER'}}
+        gdb.create_relationship(relationship_to)
+        gdb.create_relationship(relationship_from)
+
+### DATASETS
+def get_datasets_container(connection, container_id):
     restapi = f"/catalog/containers/{container_id}/children"
     url = connection['url'] + restapi
     headers = {'X-Requested-With': 'XMLHttpRequest'}
@@ -105,11 +183,24 @@ def get_datasets(connection, container_id):
     if r.status_code != 200:
         logging.error("Get metadata_datasets: {}".format(response['message']))
 
-    return response['metadata_datasets']
+    return response['datasets']
 
+# add GRAPHDB
+def add_dataset_graphdb(gdb,dataset) :
+    node_container = {'label':'CONTAINER','properties':{'id':dataset['parentId']}}
+    node_dataset = { 'label':'DATASET',
+                     'properties':{'id':dataset['id'],'name':dataset['name'],'path':dataset['qualifiedName'],
+                                   'connection_id':dataset['connectionId']}}
+    gdb.create_node(node_dataset)
+    relationship_from = {'node_from':node_container,'node_to':node_dataset,'relation':{'label':'DATASET'}}
+    gdb.create_relationship(relationship_from)
+    relationship_to = {'node_from':node_dataset,'node_to':node_container,'relation':{'label':'CONTAINER'}}
+    gdb.create_relationship(relationship_to)
+
+### DATASET ATTRIBUTES
 def get_dataset_summary(connection,dataset_name,dataset_id):
     logging.info(f"Get Dataset summary: {dataset_name}")
-    restapi = f'/catalog/metadata_datasets/{dataset_id}/summary'
+    restapi = f'catalog/datasets/{dataset_id}/summary'
     url = connection['url'][:-6] + restapi
     headers = {'X-Requested-With': 'XMLHttpRequest'}
     r = requests.get(url, headers=headers, auth=connection['auth'])
@@ -119,6 +210,36 @@ def get_dataset_summary(connection,dataset_name,dataset_id):
         logging.error("Get metadata_datasets: {}".format(response['message']))
     return response
 
+### DATASET ATTRIBUTES
+def get_dataset_factsheet(connection,connection_id,dataset_name):
+    logging.info(f"Get Dataset factsheet: {dataset_name}")
+    qualified_name = urllib.parse.quote(dataset_name,safe='')
+    restapi = f'catalog/connections/{connection_id}/datasets/{qualified_name}/factsheets'
+    url = connection['url'][:-6] + restapi
+    headers = {'X-Requested-With': 'XMLHttpRequest'}
+    r = requests.get(url, headers=headers, auth=connection['auth'])
+
+    response = json.loads(r.text)
+    if r.status_code != 200:
+        logging.error("Get dataset factsheet: {}".format(response['message']))
+    return response
+
+# add GRAPHDB
+def add_dataset_attribute_graphdb(gdb,dataset_id,attribute) :
+    node_dataset = { 'label':'DATASET','properties':{'id':dataset_id}}
+    node_attribute  = {'label':'ATTRIBUTE',
+                       'properties':{'id':attribute['name'],'dataset_id':dataset_id,'datatype':attribute['datatype']},
+                       'keys':['id','dataset_id']}
+    if 'length' in attribute:
+        node_attribute['properties']['length'] = attribute['length']
+
+    gdb.create_node(node_attribute)
+    relation_to = {'node_from':node_dataset,'node_to':node_attribute,'relation':{'label':'ATTRIBUTE'}}
+    gdb.create_relationship(relation_to)
+    relation_from = {'node_from':node_attribute,'node_to':node_dataset,'relation':{'label':'DATASET'}}
+    gdb.create_relationship(relation_from)
+
+#### DATASET TAGS
 def get_dataset_tags(connection,dataset_path,connection_id=None,tag_hierarchies=None):
     path_list = dataset_path.strip('/').split("/")
     if connection_id == None or connection_id == path_list[0]:
@@ -128,7 +249,7 @@ def get_dataset_tags(connection,dataset_path,connection_id=None,tag_hierarchies=
         qualified_name = '/'+'/'.join(path_list[0:])
 
     qualified_name = urllib.parse.quote(qualified_name,safe='')
-    restapi = f"/catalog/connections/{connection_id}/metadata_datasets/{qualified_name}/tags"
+    restapi = f"/catalog/connections/{connection_id}/datasets/{qualified_name}/tags"
     url = connection['url'] + restapi
     logging.info(f'Get Dataset Tags for: {dataset_path} ({connection_id})')
     headers = {'X-Requested-With': 'XMLHttpRequest'}
@@ -136,19 +257,30 @@ def get_dataset_tags(connection,dataset_path,connection_id=None,tag_hierarchies=
     r = requests.get(url, headers=headers, auth=connection['auth'], params=params)
 
     if r.status_code != 200:
-        logging.error(f"Get metadata_datasets attributes unsuccessful for {dataset_path}: {r.status}\n{json.loads(r.text)}")
+        logging.error(f"Get datasets attributes unsuccessful for {dataset_path}: {r.status_code}\n{json.loads(r.text)}")
         return None
     return json.loads(r.text)
 
+# add GRAPHDB
+def add_tag_relationship_graphdb(gdb,dataset_id,dataset_tags) :
+    dnode = {'label':'DATASET','properties':{'id':dataset_id}}
+    for dt in dataset_tags['tagsOnDataset']:
+        for t in dt['tags'] :
+            tnode = {'label':'CATALOG_TAG','properties':{'id':t['tag']['id']}}
+            relation_to = {'node_from':dnode,'node_to':tnode,'relation':{'label':'HAS_TAG'}}
+            relation_from = {'node_from':tnode,'node_to':dnode,'relation':{'label':'TAG'}}
+            gdb.create_relationship(relation_from)
+            gdb.create_relationship(relation_to)
+
 def export_catalog(connection) :
     containers = dict()
     datasets = list()
     datasets_cols = list()
     containers = get_containers(connection,containers)
     for name,container in containers.items() :
-        dsets = get_datasets(connection, container['id'])
-        if len(dsets) > 0:
-            logging.info(f"Scanned container:{container['qualifiedName']} - #metadata_datasets:{len(dsets)}")
+        dsets = get_datasets_container(connection, container['id'])
+        if dsets and len(dsets) > 0:
+            logging.info(f"Scanned container:{container['qualifiedName']} - #datasets:{len(dsets)}")
             datasets.extend(dsets)
 
     for dataset in datasets:
@@ -156,6 +288,9 @@ def export_catalog(connection) :
         if 'code' in ds and ds['code'] == '70016' :
             logging.warning(f"Read dataset summary for {dataset['qualifiedName']}: {ds['message']}")
             continue
+        if 'code' in ds and ds['code'] == 'internal' :
+            logging.warning(f"Read dataset summary for {dataset['qualifiedName']}: {ds['message']}")
+            continue
         for c in ds['additionalInfo']['columns']:
             length = c['length'] if 'length' in c else ''
             dtype = '' if not 'templateType' in c else c['templateType']
@@ -172,6 +307,9 @@ def export_catalog(connection) :
 
     for i,dsc in df_ds.iterrows() :
         dataset_attributes = get_dataset_tags(connection,dsc['dataset_path'],dsc['connection_id'])
+        if not dataset_attributes :
+            logging.warning("No dataset attributes!")
+            continue
         tags = dataset_attributes_str(dataset_attributes)
         df.loc[(df['connection_id'] == dsc['connection_id']) & (df['dataset_path'] == dsc['dataset_path']),'dataset_tags'] = tags['dataset_tags']
         for at,at_tags in tags['attribute_tags'].items() :
@@ -181,6 +319,46 @@ def export_catalog(connection) :
 
     return df
 
+
+def export_graphdb(connection):
+    gdb = neo4jConnection( connection['GRAPHDB']['URL']+':'+str(connection['GRAPHDB']['PORT']),
+                           connection['GRAPHDB']['USER'], connection['GRAPHDB']['PWD'],connection['GRAPHDB']['DB'])
+
+    # CATALOG
+    add_catalog_neo4j(connection)
+
+    # TENANT
+    node_tenant = {'label':'TENANT',
+                   'properties':{'tenant':connection['TENANT'],'url':connection['URL']}}
+    gdb.create_node(node_tenant)
+
+    # CONNECTIONS
+    connections = get_connections(connection)
+    add_connections_graphdb(gdb,connection,connections)
+
+    # CONTAINER
+    containers = dict()
+    get_containers(connection, containers)
+    add_containers_graphdb(gdb,containers)
+
+    # DATASETS
+    for name,container in containers.items() :
+        datasets = get_datasets_container(connection, container['id'])
+        for dataset in datasets :
+            add_dataset_graphdb(gdb,dataset)
+            # ATTRIBUTES
+            ds = get_dataset_summary(connection, dataset['qualifiedName'], dataset['id'])
+            if 'code' in ds and ds['code'] == '70016' :
+                logging.warning(f"Read dataset summary for {dataset['qualifiedName']}: {ds['message']}")
+                continue
+            for att in ds['additionalInfo']['columns']:
+                add_dataset_attribute_graphdb(gdb,dataset['id'],att)
+
+            # TAGS
+            dataset_tags = get_dataset_tags(connection, dataset['qualifiedName'], dataset['connectionId'])
+            add_tag_relationship_graphdb(gdb,dataset['id'],dataset_tags)
+
+
 # Add tag to dataset
 def add_dataset_tag(connection,dataset_path,hierarchy_id,tag_id,connection_id=None) :
 
@@ -309,7 +487,20 @@ def auto_tag(connection,metadata,tagging_map):
                             connection_id=dsc['connection_id'])
 
 
+# Trigger Profiling
+# WARNING: Private API - unsupported
+def start_profiling(connection,connection_id,connection_type,qualified_name) :
+    logging.info(f"Start Profiling: {qualified_name}")
+    restapi = f'catalog/connections/{connection_id}/datasets/{qualified_name}/factsheets'
+    url = connection['url'][:-6] + restapi
+    headers = {'X-Requested-With': 'XMLHttpRequest'}
+    params = {'connectionTypye':connection_type}
+    r = requests.post(url, headers=headers, auth=connection['auth'],params=params)
 
+    response = json.loads(r.text)
+    if r.status_code != 202:
+        logging.error("Start Profiling: {}".format(response['message']))
+    return response
 
 
 #########
@@ -325,16 +516,72 @@ if __name__ == '__main__':
     connection = {'url': urljoin(params['URL'], '/app/datahub-app-metadata/api/v1'),
             'auth': (params['TENANT'] + '\\' + params['USER'], params['PWD'])}
 
+    if 'GRAPHDB' in params:
+        connection['GRAPHDB'] = params['GRAPHDB']
+        connection['TENANT'] = params['TENANT']
+        connection['URL'] = params['URL']
+
     sysid = get_system_id(params['URL'],params['TENANT'])
 
+    NEO4J = False
+    if NEO4J:
+        export_graphdb(connection)
+
+    GET_DATASETS = False
+    if GET_DATASETS :
+        connection_id = 'HANA_Cloud_DQM'
+        datasets = get_datasets(connection, connection_id=connection_id, container_name='/')
+        for dataset in datasets:
+            q_name = dataset['remoteObjectReference']['qualifiedName']
+            dataset['tags'] = get_dataset_tags(connection,q_name,connection_id=connection_id,tag_hierarchies=None)
+        print(json.dumps(datasets,indent=4))
+
     CONNECTIONS = False
     if CONNECTIONS :
         #connection_type = "SDL"
         connection_type = ''
+        catalog_connections = False
         connections = get_connections(connection, filter_type=connection_type)
-        with open(path.join('catalog','connections_'+sysid+'.json'),'w') as fp:
+
+        with open(path.join('catalogs','catalog_connections_'+sysid+'.json'),'w') as fp:
             json.dump(connections,fp,indent=4)
 
+    ALL_CONNECTION_DATASETS = False
+    if ALL_CONNECTION_DATASETS:
+            connections = get_connections(connection)
+            with open(path.join('catalogs','all_connections_'+sysid+'.json'),'w') as fp:
+                json.dump(connections,fp,indent=4)
+            datasets = dict()
+            #for connection_id in ['ECC_IDES_GCP'] :
+            #    datasets[connection_id] = get_connection_datasets(connection,connection_id)
+            container = '/ODP_SAPI/SAP'
+            container = {'name':'SAP-R/3','qualifiedName':'/ODP_SAPI/SAP/SAP-R/3','parentQualifiedName':'/ODP_SAPI/SAP'}
+            datasets = get_connection_datasets(connection,connection_id=g.add((nsys[t['path']],ndi.parentTag,nsys[t['parent_path']])),container=container,with_details=True)
+
+            #with open(path.join('connections/snapshots','connection_datasets_'+sysid+'.json')) as fp:
+            #    latest_snapshot = json.load(fp)
+            #datasets = compare_snapshots(latest_snapshot,datasets)
+
+            #connection_id = 'S3_Catalog'
+            #connection_details = get_connection_details(connection,connection_id)
+            #connection_type = connection_details['type']
+            # Start profiling
+            #for dataset in new_datasets:
+            #    start_profiling(connection,connection_id,connection_type,dataset['qualifiedName'])
+
+            if len(datasets) >0 :
+                with open(path.join('connections/snapshots','connection_datasets_'+sysid+'.json'),'w') as fp:
+                    json.dump(datasets,fp,indent=4)
+
+    DATASET_ID = True
+    if DATASET_ID :
+        connection_id = 'HANA_Cloud_DQM'
+        dataset_qm = '/HANA_Cloud_DQM/QMGMT/CSKA'
+        datasets_ids = dict()
+        containers_ids = dict()
+        get_ids(connection, datasets_ids,containers_ids)
+        print(json.dumps(datasets_ids,indent=4))
+        print(json.dumps(containers_ids,indent=4))
 
     CONTAINER_CALL = False
     if CONTAINER_CALL :
@@ -344,25 +591,32 @@ if __name__ == '__main__':
                      'catalogObjectType': 'ROOT_FOLDER'}
 
         containers = dict()
-        container_filter = 'connectionType eq \'SDL\''
-        get_containers(connection, containers, root, container_filter=None)
+        filter = 'connectionType eq \'ABAP\''
+        filter = "name eq 'HANA_Cloud_DQM'"
+        get_containers(connection, containers, root, container_filter=filter)
+        print(json.dumps(containers,indent=4))
 
-        with open(path.join('catalogs','container_'+sysid+'.json'),'w') as fp:
-            json.dump(containers,fp,indent=4)
+        #with open(path.join('catalogs','container_'+sysid+'.json'),'w') as fp:
+        #    json.dump(containers,fp,indent=4)
 
-    GET_DATASETS = False
-    if GET_DATASETS :
+    GET_DATASETS2 = False
+    if GET_DATASETS2 :
         datasets = list()
-        with open(path.join('catalogs','container_dh-1svpfuea.dhaas-live_default.json')) as fp:
-            containers = json.load(fp)
-        for name,container in containers.items() :
-            dsets = get_datasets(connection, container['id'])
-            if len(dsets) > 0:
-                logging.info(f"Scanned container:{container['qualifiedName']} - #metadata_datasets:{len(dsets)}")
-                datasets.extend(dsets)
+        container_id ='E37E03883CE6CAE74EDB0F1D06FDBB87F919638764B727594ECBC6794D5AD685D8DF11F38A46083FAA5D04A078120AD2DC9B77A7FD00084D8F8DF3B4EE60256D'
 
-        with open(path.join('catalogs','datasets_'+sysid+'.json'),'w') as fp:
-            json.dump(datasets,fp,indent=4)
+        dsets = get_datasets_container(connection, container_id=None,container_filter=filter)
+        print(json.dumps(dsets,indent=4))
+        #with open(path.join('catalogs','container_dh-1svpfuea.dhaas-live_default.json')) as fp:
+        #    containers = json.load(fp)
+        #for name,container in containers.items() :
+        #    dsets = get_datasets_container(connection, container['id'])
+
+        #    if len(dsets) > 0:
+        #        logging.info(f"Scanned container:{container['qualifiedName']} - #metadata_datasets:{len(dsets)}")
+        #        datasets.extend(dsets)
+
+        #with open(path.join('catalogs','datasets_'+sysid+'.json'),'w') as fp:
+        #    json.dump(datasets,fp,indent=4)
 
     GET_DATASET_SUMMARY = False
     if GET_DATASET_SUMMARY :
@@ -376,13 +630,14 @@ if __name__ == '__main__':
                 continue
             for c in ds['additionalInfo']['columns']:
                 length = c['length'] if 'length' in c else ''
+                template = c['templateType'] if 'templateType' in c else ''
                 datasets_cols.append({'connection_type':ds['remoteObject']['connectionType'],
                                      'connection_id':ds['remoteObject']['connectionId'],
                                      'dataset_path':ds['remoteObject']['qualifiedName'],
                                      'dataset_name':ds['remoteObject']['name'],
                                      'column_name': c['name'],
                                      'length': length,
-                                     'dtype':c['templateType']})
+                                     'dtype':template})
 
         with open(path.join('catalogs','datasets_cols_dh-1svpfuea.dhaas-live_default.json'),'w') as fp:
             json.dump(datasets_cols, fp, indent=4)
@@ -399,6 +654,7 @@ if __name__ == '__main__':
 
         for i,dsc in df_ds.iterrows() :
             dataset_attributes = get_dataset_tags(connection, dsc['dataset_path'], dsc['connection_id'])
+
             tags = dataset_attributes_str(dataset_attributes)
             df.loc[(df['connection_id'] == dsc['connection_id']) & (df['dataset_path'] == dsc['dataset_path']),'dataset_tags'] = tags['dataset_tags']
             for at,at_tags in tags['attribute_tags'].items() :
@@ -426,7 +682,7 @@ if __name__ == '__main__':
                 tag_id = hierarchies[ast]['tag_id']
                 add_dataset_attribute_tag(connection, ds, hierarchy_id, tag_id, attribute)
 
-    EXPORT = True
+    EXPORT = False
     if EXPORT :
         df = export_catalog(connection)
         df.to_csv(path.join('catalogs','metadata_'+sysid+'.csv'),index=False)
